==> haskell-hspec-expectations-lifted-0.10.0-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations-lifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-C6VEtu9DC4Z7z40jXkzxXF
key:                  hspec-expectations-lifted-0.10.0-C6VEtu9DC4Z7z40jXkzxXF
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  59f2e0f72df9b68bb0b1efd678791c25
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-C6VEtu9DC4Z7z40jXkzxXF
depends:
    base-4.16.4.0 hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-lifted-0.10.0-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations-lifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-9FEOaB8x0ff1eKDeNQDtcV
key:                  hspec-expectations-lifted-0.10.0-9FEOaB8x0ff1eKDeNQDtcV
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  3977b6a20e94b08a1bee45eb52abd9a5
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-9FEOaB8x0ff1eKDeNQDtcV
depends:
    base-4.16.4.0 hspec-expectations-0.8.3-53KTMpuZLbD4EdixkL29oj
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
